@@ -37,18 +37,13 @@ static gboolean mousepad_close_button_leave_notify_event (GtkWidget        *widg
 
 
 
-struct MousepadCloseButton_
+struct _MousepadCloseButton
 {
   GtkButton parent;
 
   GtkTextBuffer *buffer;
 };
 
-struct MousepadCloseButtonClass_
-{
-  GtkButtonClass  parent_class;
-};
-
 
 
 G_DEFINE_TYPE (MousepadCloseButton, mousepad_close_button, GTK_TYPE_BUTTON)
