@@ -54,8 +54,9 @@ G_BEGIN_DECLS
 #define MOUSEPAD_ID_LEN G_N_ELEMENTS (MOUSEPAD_ID) - 1
 
 /* config file locations */
-#define MOUSEPAD_RC_RELPATH     ("Mousepad" G_DIR_SEPARATOR_S "mousepadrc")
-#define MOUSEPAD_ACCELS_RELPATH ("Mousepad" G_DIR_SEPARATOR_S "accels.scm")
+#define MOUSEPAD_SETTINGS_RELPATH ("Mousepad" G_DIR_SEPARATOR_S "settings.conf")
+#define MOUSEPAD_RC_RELPATH       ("Mousepad" G_DIR_SEPARATOR_S "mousepadrc")
+#define MOUSEPAD_ACCELS_RELPATH   ("Mousepad" G_DIR_SEPARATOR_S "accels.scm")
 
 /* handling flags */
 #define MOUSEPAD_SET_FLAG(flags, flag)   G_STMT_START{ ((flags) |= (flag)); }G_STMT_END
@@ -69,8 +70,8 @@ G_BEGIN_DECLS
 #define TIMER_STOP      TIMER_SPLIT g_timer_destroy (__FUNCTION__timer);
 
 #define PRINT_LOCATION  g_printerr ("%s\n", G_STRLOC);
-#define TRACE(fmt, var) G_STMT_START{ g_printerr ("%s:%s: ", G_STRLOC, #var); \
-                                      g_printerr (fmt, var); g_printerr ("\n"); }G_STMT_END
+#define RTRACE(fmt, var) G_STMT_START{ g_printerr ("%s:%s: ", G_STRLOC, #var); \
+                                       g_printerr (fmt, var); g_printerr ("\n"); }G_STMT_END
 
 /* optimize the properties */
 #define MOUSEPAD_PARAM_READWRITE (G_PARAM_READWRITE | G_PARAM_STATIC_NAME \
