@@ -27,7 +27,7 @@
 
 
 
-struct MousepadSettingsStore_
+struct _MousepadSettingsStore
 {
   GObject parent;
 
@@ -38,13 +38,6 @@ struct MousepadSettingsStore_
 
 
 
-struct MousepadSettingsStoreClass_
-{
-  GObjectClass parent_class;
-};
-
-
-
 typedef struct
 {
   const gchar *name;
