@@ -27,6 +27,7 @@ G_BEGIN_DECLS
 #define MOUSEPAD_SETTING_MAKE_BACKUP                  "preferences.file.make-backup"
 #define MOUSEPAD_SETTING_MONITOR_CHANGES              "preferences.file.monitor-changes"
 #define MOUSEPAD_SETTING_MONITOR_DISABLING_TIMER      "preferences.file.monitor-disabling-timer"
+#define MOUSEPAD_SETTING_AUTO_RELOAD                  "preferences.file.auto-reload"
 #define MOUSEPAD_SETTING_SESSION_RESTORE              "preferences.file.session-restore"
 #define MOUSEPAD_SETTING_AUTOSAVE_TIMER               "preferences.file.autosave-timer"
 
@@ -87,6 +88,9 @@ G_BEGIN_DECLS
 #define MOUSEPAD_SETTING_SEARCH_REPLACE_ALL_LOCATION  "state.search.replace-all-location"
 #define MOUSEPAD_SETTING_SEARCH_HIGHLIGHT_ALL         "state.search.highlight-all"
 #define MOUSEPAD_SETTING_SEARCH_INCREMENTAL           "state.search.incremental"
+#define MOUSEPAD_SETTING_SEARCH_HISTORY_SIZE          "state.search.history-size"
+#define MOUSEPAD_SETTING_SEARCH_SEARCH_HISTORY        "state.search.search-history"
+#define MOUSEPAD_SETTING_SEARCH_REPLACE_HISTORY       "state.search.replace-history"
 
 #define MOUSEPAD_SETTING_WINDOW_HEIGHT                "state.window.height"
 #define MOUSEPAD_SETTING_WINDOW_WIDTH                 "state.window.width"
