@@ -15,7 +15,6 @@
  */
 
 #include <mousepad/mousepad-private.h>
-#include <mousepad/mousepad-plugin.h>
 #include <mousepad/mousepad-application.h>
 #include <mousepad/mousepad-window.h>
 #include <mousepad/mousepad-view.h>
@@ -58,11 +57,6 @@ static void gspell_plugin_view_menu_deactivate (GspellPlugin     *plugin,
 
 
 
-struct _GspellPluginClass
-{
-  MousepadPluginClass __parent__;
-};
-
 struct _GspellPlugin
 {
   MousepadPlugin __parent__;
